"""Added source type to adviser run table

Revision ID: d77154f3c15f
Revises: 7c261487d4d4
Create Date: 2020-06-30 00:59:47.273996+00:00

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql

# revision identifiers, used by Alembic.
revision = 'd77154f3c15f'
down_revision = '7c261487d4d4'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    source_type = postgresql.ENUM('CLI', 'KEBECHET', 'S2I', 'GITHUB_APP', 'JUPYTER_NOTEBOOK', name='source_type')
    source_type.create(op.get_bind())
    op.add_column('adviser_run', sa.Column('source_type', sa.Enum('CLI', 'KEBECHET', 'S2I', 'GITHUB_APP', 'JUPYTER_NOTEBOOK', name='source_type'), nullable=True))
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('adviser_run', 'source_type')
    source_type = postgresql.ENUM('CLI', 'KEBECHET', 'S2I', 'GITHUB_APP', 'JUPYTER_NOTEBOOK', name='source_type')
    source_type.drop(op.get_bind())
    # ### end Alembic commands ###



"""Flag for if specific hash has gone missing, defaults to present

Revision ID: ecb0ca258835
Revises: 0ea53ec16d6b
Create Date: 2020-03-26 15:26:00.311857+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'ecb0ca258835'
down_revision = '0ea53ec16d6b'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('python_artifact', sa.Column('present', sa.Boolean(), nullable=False, server_default="true"))
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('python_artifact', 'present')
    # ### end Alembic commands ###



"""Create index for CVE step

Revision ID: af2b9e09e53e
Revises: 9fea7ca59f56
Create Date: 2020-01-08 13:25:27.881950+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'af2b9e09e53e'
down_revision = '9fea7ca59f56'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_index('has_vulnerability_python_package_version_entity_idx', 'has_vulnerability', ['python_package_version_entity_id'], unique=False)
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index('has_vulnerability_python_package_version_entity_idx', table_name='has_vulnerability')
    # ### end Alembic commands ###



"""Added kebechet manager and last run columns

Revision ID: 4461784e248a
Revises: b9f960cdd223
Create Date: 2020-09-29 18:08:42.771601+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '4461784e248a'
down_revision = 'b9f960cdd223'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('kebechet_github_installations', sa.Column('info_manager', sa.Boolean(), server_default='false', nullable=False))
    op.add_column('kebechet_github_installations', sa.Column('last_run', sa.DateTime(), nullable=True))
    op.add_column('kebechet_github_installations', sa.Column('pipfile_requirements_manager', sa.Boolean(), server_default='false', nullable=False))
    op.add_column('kebechet_github_installations', sa.Column('thoth_advise_manager', sa.Boolean(), server_default='false', nullable=False))
    op.add_column('kebechet_github_installations', sa.Column('thoth_provenance_manager', sa.Boolean(), server_default='false', nullable=False))
    op.add_column('kebechet_github_installations', sa.Column('update_manager', sa.Boolean(), server_default='false', nullable=False))
    op.add_column('kebechet_github_installations', sa.Column('version_manager', sa.Boolean(), server_default='false', nullable=False))
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('kebechet_github_installations', 'version_manager')
    op.drop_column('kebechet_github_installations', 'update_manager')
    op.drop_column('kebechet_github_installations', 'thoth_provenance_manager')
    op.drop_column('kebechet_github_installations', 'thoth_advise_manager')
    op.drop_column('kebechet_github_installations', 'pipfile_requirements_manager')
    op.drop_column('kebechet_github_installations', 'last_run')
    op.drop_column('kebechet_github_installations', 'info_manager')
    # ### end Alembic commands ###



"""add is_external to PackageExtractRun

Revision ID: 079e1d92f9d4
Revises: 650a13fd0a08
Create Date: 2019-10-08 12:33:51.979019+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '079e1d92f9d4'
down_revision = '650a13fd0a08'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('has_symbol', sa.Column('external_software_environment_id', sa.Integer(), nullable=False))
    op.create_foreign_key(None, 'has_symbol', 'external_software_environment', ['external_software_environment_id'], ['id'], ondelete='CASCADE')
    op.add_column('package_extract_run', sa.Column('external_software_environment_id', sa.Integer(), nullable=False))
    op.create_foreign_key(None, 'package_extract_run', 'external_software_environment', ['external_software_environment_id'], ['id'], ondelete='CASCADE')
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_constraint(None, 'package_extract_run', type_='foreignkey')
    op.drop_column('package_extract_run', 'external_software_environment_id')
    op.drop_constraint(None, 'has_symbol', type_='foreignkey')
    op.drop_column('has_symbol', 'external_software_environment_id')
    # ### end Alembic commands ###



"""add flag to indicate missing source code

Revision ID: c8017a5b43f1
Revises: 6389973bd8b6
Create Date: 2020-09-28 15:11:48.986072+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'c8017a5b43f1'
down_revision = '6389973bd8b6'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('python_package_version', sa.Column('is_downloadable', sa.Boolean(), nullable=False, server_default="true"))
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('python_package_version', 'is_downloadable')
    # ### end Alembic commands ###



"""Added PythonPackageMetadata table

Revision ID: e05d6d95ea95
Revises: 74f68dabbb46
Create Date: 2019-10-15 16:59:27.902479+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'e05d6d95ea95'
down_revision = '74f68dabbb46'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('python_package_metadata',
    sa.Column('id', sa.Integer(), autoincrement=True, nullable=False),
    sa.Column('author', sa.String(length=256), nullable=True),
    sa.Column('author_email', sa.String(length=256), nullable=True),
    sa.Column('classifier', sa.String(length=256), nullable=True),
    sa.Column('download_url', sa.String(length=256), nullable=True),
    sa.Column('home_page', sa.String(length=256), nullable=True),
    sa.Column('keywords', sa.String(length=256), nullable=True),
    sa.Column('license', sa.String(length=256), nullable=True),
    sa.Column('maintainer', sa.String(length=256), nullable=True),
    sa.Column('maintainer_email', sa.String(length=256), nullable=True),
    sa.Column('metadata_version', sa.String(length=256), nullable=True),
    sa.Column('name', sa.String(length=256), nullable=True),
    sa.Column('platform', sa.String(length=256), nullable=True),
    sa.Column('requires_dist', sa.String(length=256), nullable=True),
    sa.Column('summary', sa.String(length=256), nullable=True),
    sa.Column('version', sa.String(length=256), nullable=True),
    sa.PrimaryKeyConstraint('id')
    )
    op.add_column('python_package_version', sa.Column('python_package_metadata_id', sa.Integer(), nullable=True))
    op.create_foreign_key(None, 'python_package_version', 'python_package_metadata', ['python_package_metadata_id'], ['id'], ondelete='CASCADE')
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_constraint(None, 'python_package_version', type_='foreignkey')
    op.drop_column('python_package_version', 'python_package_metadata_id')
    op.drop_table('python_package_metadata')
    # ### end Alembic commands ###



"""change flag to 'provides_source_distro'

Revision ID: b9f960cdd223
Revises: cd34fd8a5a90
Create Date: 2020-09-29 17:50:13.094530+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'b9f960cdd223'
down_revision = 'cd34fd8a5a90'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.alter_column('python_package_version', 'is_si_analyzable', new_column_name='provides_source_distro')
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.alter_column('python_package_version', 'provides_source_distro', new_column_name='is_si_analyzable')
    # ### end Alembic commands ###



"""Create indexes for has_artifact table

Revision ID: bb26306538f0
Revises: 7d970baad7f2
Create Date: 2020-01-15 11:30:42.763848+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'bb26306538f0'
down_revision = '7d970baad7f2'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_index('has_artifact_python_artifact_id', 'has_artifact', ['python_artifact_id'], unique=False)
    op.create_index('has_artifact_python_package_version_entity_id', 'has_artifact', ['python_package_version_entity_id'], unique=False)
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index('has_artifact_python_package_version_entity_id', table_name='has_artifact')
    op.drop_index('has_artifact_python_artifact_id', table_name='has_artifact')
    # ### end Alembic commands ###



"""Add performance and security enums for recommendation types

Revision ID: 83e2900c3721
Revises: d6d0b20ec650
Create Date: 2020-08-19 06:49:24.347264+00:00

"""
from alembic import op
import sqlalchemy as sa

# revision identifiers, used by Alembic.
revision = '83e2900c3721'
down_revision = 'd6d0b20ec650'
branch_labels = None
depends_on = None

# Solution based on https://stackoverflow.com/a/33617845

name = 'recommendation_type'
tmp_name = 'tmp_' + name

old_options = ('STABLE', 'TESTING', 'LATEST')
new_options = sorted(old_options + ('PERFORMANCE', 'SECURITY'))

new_type = sa.Enum(*new_options, name=name)
old_type = sa.Enum(*old_options, name=name)

tcr = sa.sql.table('adviser_run',
                   sa.Column('recommendation_type', new_type, nullable=False))

def upgrade():
    op.execute('ALTER TYPE ' + name + ' RENAME TO ' + tmp_name)

    new_type.create(op.get_bind())
    op.execute('ALTER TABLE adviser_run ALTER COLUMN recommendation_type ' +
               'TYPE ' + name + ' USING recommendation_type::text::' + name)
    op.execute('DROP TYPE ' + tmp_name)


def downgrade():
    # Convert 'performance' recommendation type into 'stable'                                                                                                                      
    # Convert 'security' recommendation type into 'stable'                                                                                                                      
    op.execute(tcr.update().where(tcr.c.recommendation_type=='PERFORMANCE')
               .values(recommendation_type='STABLE'))
    op.execute(tcr.update().where(tcr.c.recommendation_type=='SECURITY')
               .values(recommendation_type='STABLE'))

    op.execute('ALTER TYPE ' + name + ' RENAME TO ' + tmp_name)

    old_type.create(op.get_bind())
    op.execute('ALTER TABLE adviser_run ALTER COLUMN recommendation_type ' +
               'TYPE ' + name + ' USING recommendation_type::text::' + name)
    op.execute('DROP TYPE ' + tmp_name)



"""add flag to indicate failed si

Revision ID: 342d45db2dc2
Revises: 4461784e248a
Create Date: 2020-10-19 18:33:43.655157+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '342d45db2dc2'
down_revision = '4461784e248a'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('si_aggregated_run', sa.Column('error', sa.Boolean(), nullable=False, server_default='false'))
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('si_aggregated_run', 'error')
    # ### end Alembic commands ###



"""Created tables for metadata multi part keys

Revision ID: 7866a83369ff
Revises: dd19dd789f6d
Create Date: 2019-11-05 14:25:01.902734+00:00

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql

# revision identifiers, used by Alembic.
revision = '7866a83369ff'
down_revision = 'dd19dd789f6d'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('python_package_metadata_classifier',
    sa.Column('id', sa.Integer(), autoincrement=True, nullable=False),
    sa.Column('classifier', sa.String(length=256), nullable=True),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('python_package_metadata_distutils',
    sa.Column('id', sa.Integer(), autoincrement=True, nullable=False),
    sa.Column('distutils', sa.String(length=256), nullable=True),
    sa.Column('distutils_type', postgresql.ENUM('REQUIRED', 'PROVIDED', 'OBSOLETE', name='distutils_type'), nullable=True),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('python_package_metadata_platform',
    sa.Column('id', sa.Integer(), autoincrement=True, nullable=False),
    sa.Column('platform', sa.String(length=256), nullable=True),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('python_package_metadata_project_url',
    sa.Column('id', sa.Integer(), autoincrement=True, nullable=False),
    sa.Column('project_url', sa.String(length=256), nullable=True),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('python_package_metadata_provides_extra',
    sa.Column('id', sa.Integer(), autoincrement=True, nullable=False),
    sa.Column('optional_feature', sa.String(length=256), nullable=True),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('python_package_metadata_requires_external',
    sa.Column('id', sa.Integer(), autoincrement=True, nullable=False),
    sa.Column('dependency', sa.String(length=256), nullable=True),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('python_package_metadata_supported_platform',
    sa.Column('id', sa.Integer(), autoincrement=True, nullable=False),
    sa.Column('supported_platform', sa.String(length=256), nullable=True),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('has_metadata_classifier',
    sa.Column('id', sa.Integer(), autoincrement=True, nullable=False),
    sa.Column('python_package_metadata_id', sa.Integer(), nullable=False),
    sa.Column('python_package_metadata_classifier_id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['python_package_metadata_classifier_id'], ['python_package_metadata_classifier.id'], ondelete='CASCADE'),
    sa.ForeignKeyConstraint(['python_package_metadata_id'], ['python_package_metadata.id'], ondelete='CASCADE'),
    sa.PrimaryKeyConstraint('id', 'python_package_metadata_id', 'python_package_metadata_classifier_id')
    )
    op.create_table('has_metadata_distutils',
    sa.Column('id', sa.Integer(), autoincrement=True, nullable=False),
    sa.Column('python_package_metadata_id', sa.Integer(), nullable=False),
    sa.Column('python_package_metadata_distutils_id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['python_package_metadata_distutils_id'], ['python_package_metadata_distutils.id'], ondelete='CASCADE'),
    sa.ForeignKeyConstraint(['python_package_metadata_id'], ['python_package_metadata.id'], ondelete='CASCADE'),
    sa.PrimaryKeyConstraint('id', 'python_package_metadata_id', 'python_package_metadata_distutils_id')
    )
    op.create_table('has_metadata_platform',
    sa.Column('id', sa.Integer(), autoincrement=True, nullable=False),
    sa.Column('python_package_metadata_id', sa.Integer(), nullable=False),
    sa.Column('python_package_metadata_platform_id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['python_package_metadata_id'], ['python_package_metadata.id'], ondelete='CASCADE'),
    sa.ForeignKeyConstraint(['python_package_metadata_platform_id'], ['python_package_metadata_platform.id'], ondelete='CASCADE'),
    sa.PrimaryKeyConstraint('id', 'python_package_metadata_id', 'python_package_metadata_platform_id')
    )
    op.create_table('has_metadata_project_url',
    sa.Column('id', sa.Integer(), autoincrement=True, nullable=False),
    sa.Column('python_package_metadata_id', sa.Integer(), nullable=False),
    sa.Column('python_package_metadata_project_url_id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['python_package_metadata_id'], ['python_package_metadata.id'], ondelete='CASCADE'),
    sa.ForeignKeyConstraint(['python_package_metadata_project_url_id'], ['python_package_metadata_project_url.id'], ondelete='CASCADE'),
    sa.PrimaryKeyConstraint('id', 'python_package_metadata_id', 'python_package_metadata_project_url_id')
    )
    op.create_table('has_metadata_provides_extra',
    sa.Column('id', sa.Integer(), autoincrement=True, nullable=False),
    sa.Column('python_package_metadata_id', sa.Integer(), nullable=False),
    sa.Column('python_package_metadata_provides_extra_id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['python_package_metadata_id'], ['python_package_metadata.id'], ondelete='CASCADE'),
    sa.ForeignKeyConstraint(['python_package_metadata_provides_extra_id'], ['python_package_metadata_provides_extra.id'], ondelete='CASCADE'),
    sa.PrimaryKeyConstraint('id', 'python_package_metadata_id', 'python_package_metadata_provides_extra_id')
    )
    op.create_table('has_metadata_requires_external',
    sa.Column('id', sa.Integer(), autoincrement=True, nullable=False),
    sa.Column('python_package_metadata_id', sa.Integer(), nullable=False),
    sa.Column('python_package_metadata_requires_external_id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['python_package_metadata_id'], ['python_package_metadata.id'], ondelete='CASCADE'),
    sa.ForeignKeyConstraint(['python_package_metadata_requires_external_id'], ['python_package_metadata_requires_external.id'], ondelete='CASCADE'),
    sa.PrimaryKeyConstraint('id', 'python_package_metadata_id', 'python_package_metadata_requires_external_id')
    )
    op.create_table('has_metadata_supported_platform',
    sa.Column('id', sa.Integer(), autoincrement=True, nullable=False),
    sa.Column('python_package_metadata_id', sa.Integer(), nullable=False),
    sa.Column('python_package_metadata_supported_platform_id', sa.Integer(), nullable=False),
    sa.ForeignKeyConstraint(['python_package_metadata_id'], ['python_package_metadata.id'], ondelete='CASCADE'),
    sa.ForeignKeyConstraint(['python_package_metadata_supported_platform_id'], ['python_package_metadata_supported_platform.id'], ondelete='CASCADE'),
    sa.PrimaryKeyConstraint('id', 'python_package_metadata_id', 'python_package_metadata_supported_platform_id')
    )
    op.add_column('python_package_metadata', sa.Column('description', sa.String(length=256), nullable=True))
    op.drop_column('python_package_metadata', 'classifier')
    op.drop_column('python_package_metadata', 'requires_dist')
    op.drop_column('python_package_metadata', 'provides_extra')
    op.drop_column('python_package_metadata', 'project_url')
    op.drop_column('python_package_metadata', 'platform')
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('python_package_metadata', sa.Column('platform', sa.VARCHAR(length=256), autoincrement=False, nullable=True))
    op.add_column('python_package_metadata', sa.Column('project_url', sa.VARCHAR(length=256), autoincrement=False, nullable=True))
    op.add_column('python_package_metadata', sa.Column('provides_extra', sa.VARCHAR(length=256), autoincrement=False, nullable=True))
    op.add_column('python_package_metadata', sa.Column('requires_dist', sa.VARCHAR(length=256), autoincrement=False, nullable=True))
    op.add_column('python_package_metadata', sa.Column('classifier', sa.VARCHAR(length=256), autoincrement=False, nullable=True))
    op.drop_column('python_package_metadata', 'description')
    op.drop_table('has_metadata_supported_platform')
    op.drop_table('has_metadata_requires_external')
    op.drop_table('has_metadata_provides_extra')
    op.drop_table('has_metadata_project_url')
    op.drop_table('has_metadata_platform')
    op.drop_table('has_metadata_distutils')
    op.drop_table('has_metadata_classifier')
    op.drop_table('python_package_metadata_supported_platform')
    op.drop_table('python_package_metadata_requires_external')
    op.drop_table('python_package_metadata_provides_extra')
    op.drop_table('python_package_metadata_project_url')
    op.drop_table('python_package_metadata_platform')
    op.drop_table('python_package_metadata_distutils')
    op.drop_table('python_package_metadata_classifier')
    # ### end Alembic commands ###
